@@ -90,7 +90,7 @@ gl.drop.ind <- function(x,
     x <- x[inds_to_drop,]
 
     # Monomorphic loci may have been created
-    x@other$loc.metrics.flags$monomorphs == FALSE
+    x@other$loc.metrics.flags$monomorphs <- FALSE
     
     # Remove monomorphic loci
     if (mono.rm) {
