@@ -84,11 +84,12 @@ gl.hwe.pop <-  function(x,
     # FUNCTION SPECIFIC ERROR CHECKING check if packages is installed
     pkg <- "HardyWeinberg"
     if (!(requireNamespace(pkg, quietly = TRUE))) {
-        stop(error(
-            "Package",
-            pkg,
-            " needed for this function to work. Please install it."
-        ))
+      cat(error(
+        "Package",
+        pkg,
+        " needed for this function to work. Please install it.\n"
+      ))
+      return(-1)
     }
     
     # Set a population if none is specified (such as if the genlight object has been generated manually)
