@@ -50,11 +50,12 @@ gl2genalex <- function(x,
     # CHECK IF PACKAGES ARE INSTALLED
     pkg <- "poppr"
     if (!(requireNamespace(pkg, quietly = TRUE))) {
-        stop(error(
-            "Package",
-            pkg,
-            " needed for this function to work. Please install it."
-        ))
+      cat(error(
+        "Package",
+        pkg,
+        " needed for this function to work. Please install it.\n"
+      ))
+      return(-1)
     }
     
     # DO THE JOB
